%define revdns  org.shotcut.Shotcut

Name:           shotcut
Version:        19.09.14
Release:        %mkrel 1
Summary:        A free, open source, cross-platform video editor
Group:          Video/Editors and Converters
# The entire source code is GPLv3+ except mvcp/ which is LGPLv2+
License:        GPLv3+ and LGPLv2+
URL:            https://www.shotcut.org
Source0:        https://github.com/mltframework/shotcut/archive/v%{version}/%{name}-%{version}.tar.gz
# Disable update checks, won't work on packaged version
Patch0:         shotcut-18.05.08-mga-disable-upgrade-check.patch
# Looks for "qmelt" (unpackaged), but "melt" is enough for us:
# https://github.com/mltframework/shotcut/issues/370
Patch1:         shotcut-18.05.08-mga-use-melt-on-linux.patch

BuildRequires:  pkgconfig(mlt++)
BuildRequires:  pkgconfig(mlt-framework)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.9.1
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5QuickWidgets)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  qttools5
# (akien) Not packaged yet in Mageia
#BuildRequires:  webvfx-devel

# Apparently dependencies are dlopen()'ed
# To be confirmed, but for now requiring to avoid issues
Requires:       frei0r
Requires:       gstreamer1.0-plugins-bad
Requires:       gstreamer1.0-plugins-good
Requires:       gstreamer1.0-plugins-ugly
Requires:       ladspa
Requires:       lame
Requires:       ffmpeg
Requires:       mlt
Requires:       qtquickcontrols5
Requires:       qtgraphicaleffects5
Requires:       qtmultimedia5

%description
Shotcut is a free and open-source cross-platform video editing application for
Windows, OS X, and Linux.

Shotcut supports many video, audio, and image formats via FFmpeg and screen,
webcam, and audio capture. It uses a time-line for non-linear video editing of
multiple tracks that may be composed of various file formats. Scrubbing and
transport control are assisted by OpenGL GPU-based processing and a number of
video and audio filters are available.

%prep
%autosetup -p1

# Postmortem debugging tools for MinGW.
rm -rf drmingw

%build
%qmake_qt5 \
  PREFIX=%{_prefix} \
  SHOTCUT_VERSION="%{version}-%{release}"
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}

# List language files
for path in %{buildroot}%{_datadir}/%{name}/translations/*; do
  file=$(basename $path)
  lang=$(echo $file | sed -e "s/shotcut_\([A-Za-z_]*\)\.qm/\1/")
  path=$(echo $path | sed -e "s|%{buildroot}||")
  echo "%lang($lang) $path" >> "%{name}.lang"
done

%files -f %{name}.lang
%doc README.md
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{revdns}.desktop
%{_datadir}/metainfo/%{revdns}.appdata.xml
%{_datadir}/mime/packages/%{revdns}.xml
%{_iconsdir}/hicolor/64x64/apps/%{revdns}.png
%{_mandir}/man1/%{name}.1*


%changelog
* Wed Oct 02 2019 akien <akien> 19.09.14-1.mga7
+ Revision: 1448848
- Version 19.04.14

* Tue Apr 02 2019 umeabot <umeabot> 18.12.23-2.mga7
+ Revision: 1384795
- Qt5 Rebuild

* Sun Jan 13 2019 akien <akien> 18.12.23-1.mga7
+ Revision: 1355867
- Version 18.12.23

* Sun Sep 23 2018 umeabot <umeabot> 18.05.08-2.mga7
+ Revision: 1301018
- Mageia 7 Mass Rebuild

* Tue May 29 2018 akien <akien> 18.05.08-1.mga7
+ Revision: 1232937
- Add RPM group
- Simplify packaging
  o Remove lang subpackages, properly use .lang file
  o Remove doc subpackage
  o Disable update checks instead of trying to hack it away
  o Reorder BuildRequires
- import shortcut-18.05.08-1.fc29.src.rpm from RPM Fusion

